@@ -1,4 +1,4 @@
-#define VERSION "1.85a"
+#define VERSION "1.86"
 
 /*
  *  units, a program for units conversion
@@ -72,8 +72,7 @@ char *unitsfiles[MAXFILES+1];   /* Null terminated list of units file names */
 char *progname="units";         /* Used in error messages */
 char *queryhave = "You have: "; /* Prompt text for units to convert from */
 char *querywant = "You want: "; /* Prompt text for units to convert to */
-
-
+char *deftext="\tDefinition: "; /* Output text when printing definition */
 
 #define  HASHSIZE 101           /* Straight from K&R */
 #define  HASHNUMBER 31
@@ -1618,7 +1617,7 @@ void
 showdefinition(char *unitstr, struct unittype *theunit)
 {
   unitstr = removepadding(unitstr);
-  printf("\tDefinition: ");
+  printf("%s",deftext);
   unitstr = lookupunit(unitstr,1);
   while(unitstr && strspn(unitstr,"0123456789.") != strlen(unitstr) && 
 	!strchr(unitstr,PRIMITIVECHAR)) {
@@ -1635,9 +1634,11 @@ showfuncdefinition(struct func *fun)
   int i;
 
   if (fun->table){  /* It's a table */
-    printf("\tDefinition: interpolated table with points\n");
+    printf("%sinterpolated table with points\n",deftext);
     for(i=0;i<fun->tablelen;i++){
-      printf("\t\t    %s(", fun->name);
+      if (verbose>0)
+        printf("\t\t    ");
+      printf("%s(", fun->name);
       printf(numformat, fun->table[i].location);
       printf(") = ");
       printf(numformat, fun->table[i].value);
@@ -1647,7 +1648,7 @@ showfuncdefinition(struct func *fun)
     }
     return;
   }
-  printf("\tDefinition: %s(%s) = %s\n", fun->name, fun->forward.param,
+  printf("%s%s(%s) = %s\n", deftext, fun->name, fun->forward.param,
 	 fun->forward.def);
     
 }
@@ -2083,7 +2084,7 @@ usage()
         --check-verbose like --check, but lists units as they are checked\n\
         --verbose-check   so you can find units that cause endless loops\n\
     -e, --exponential   exponential format output\n\
-    -f, --file          specify a units data files (-f '' loads default file)\n\
+    -f, --file          specify a units data file (-f '' loads default file)\n\
     -m, --minus         make - into a subtraction operator (default)\n\
     -o, --output-format specify printf numeric output format\n\
     -p, --product       make - into a product operator\n\
@@ -2112,7 +2113,7 @@ void
 printversion()
 {
   printf("GNU Units version %s\n%s, units database in %s\n\
-Copyright (C) 2004 Free Software Foundation, Inc.\n\
+Copyright (C) 2006 Free Software Foundation, Inc.\n\
 GNU Units comes with ABSOLUTELY NO WARRANTY.\n\
 You may redistribute copies of GNU Units\n\
 under the terms of the GNU General Public License.\n\n", 
@@ -2377,26 +2378,34 @@ processargs(int argc, char **argv, char **from, char **to)
 	 case 'h':
 	    usage();
 	    break;
-	 default:
+         default:
             helpmsg();
       } 
    }
-   if (optind == argc - 2) {
-      quiet=1;
-      *from = argv[optind];
-      *to = argv[optind+1]; 
-      return 0;
-   }
 
-   if (optind == argc - 1) {
-      quiet=1;
-      *from = argv[optind];
-      *to=0;
-      return 0;
-   }
-   if (optind < argc - 2) {
-      fprintf(stderr,"Too many arguments (maybe you need quotes).\n");
-      helpmsg();
+   if (unitcheck) {
+     if (optind != argc){
+       fprintf(stderr, "Too many arguments (arguments are not allowed with -c).\n");
+       helpmsg();
+     }
+   } else {
+     if (optind == argc - 2) {
+        quiet=1;
+        *from = argv[optind];
+        *to = argv[optind+1]; 
+        return 0;
+     }
+
+     if (optind == argc - 1) {
+        quiet=1;
+        *from = argv[optind];
+        *to=0;
+        return 0;
+     }
+     if (optind < argc - 2) {
+        fprintf(stderr,"Too many arguments (maybe you need quotes).\n");
+        helpmsg();
+     }
    }
    return 1;
 }
@@ -2423,7 +2432,9 @@ processunit(struct unittype *theunit, char *unitstr, char *prompt, int pointer)
   if (err=parseunit(theunit, unitstr, &errmsg, &errloc)){
     if (pointer){
       if (err!=E_UNKNOWNUNIT || !irreducible){
-        while(*prompt++) putchar(' ');
+	if (!quiet) {
+          while(*prompt++) putchar(' ');
+	}
 	if (errloc>0)  
 	  while(--errloc) putchar(' ');
 	printf("^\n");
@@ -2560,6 +2571,9 @@ main(int argc, char **argv)
 
    interactive = processargs(argc, argv, &havestr, &wantstr);
 
+   if (verbose==0)
+     deftext = "";
+
    if (!unitsfiles[0]){
      unitsfiles[0] = getenv("UNITSFILE");
      if (!unitsfiles[0])
